"""Test levenshtein."""
import unittest
from diarizationlm import levenshtein


class LevenshteinTest(unittest.TestCase):

  def test_levenshtein_with_edits_1(self):
    s1 = "a b"
    s2 = "a c"
    align = levenshtein.levenshtein_with_edits(s1, s2)
    self.assertEqual(1, align[0])
    self.assertListEqual([(0, 0), (1, 1)], align[1])

  def test_levenshtein_with_edits_2(self):
    s1 = "hello good morning how are you"
    s2 = "hello morning hi how are you"
    align = levenshtein.levenshtein_with_edits(s1, s2)
    self.assertEqual(2, align[0])
    self.assertListEqual(
      [(0, 0), (1, -1), (2, 1), (-1, 2), (3, 3), (4, 4), (5, 5)],
      align[1])

  def test_levenshtein_with_edit_multiple_spaces(self):
    s1 = "     hello  good    morning how are you"
    s2 = "hello morning hi how    are you  "
    align = levenshtein.levenshtein_with_edits(s1, s2)
    self.assertEqual(2, align[0])
    self.assertListEqual(
      [(0, 0), (1, -1), (2, 1), (-1, 2), (3, 3), (4, 4), (5, 5)],
      align[1])


if __name__ == "__main__":
  unittest.main()



"""__init__ file."""

from . import levenshtein
from . import utils
from . import metrics

levenshtein_with_edits = levenshtein.levenshtein_with_edits
PromptOptions = utils.PromptOptions
transcript_preserving_speaker_transfer = (
    utils.transcript_preserving_speaker_transfer)
ref_to_oracle = utils.ref_to_oracle
hyp_to_degraded = utils.hyp_to_degraded
create_diarized_text = utils.create_diarized_text
extract_text_and_spk = utils.extract_text_and_spk
JsonUtteranceReader = utils.JsonUtteranceReader
generate_prompts = utils.generate_prompts
postprocess_completions_for_utt = utils.postprocess_completions_for_utt
UtteranceMetrics = metrics.UtteranceMetrics
compute_utterance_metrics = metrics.compute_utterance_metrics
compute_metrics_on_json_dict = metrics.compute_metrics_on_json_dict
